@@ -371,6 +371,9 @@ INVALIDPARAMETERVALUE_INVALIDPID = 'InvalidParameterValue.InvalidPid'
 # 只读实例组状态错误。
 INVALIDPARAMETERVALUE_INVALIDREADONLYGROUPSTATUS = 'InvalidParameterValue.InvalidReadOnlyGroupStatus'
 
+# 无效地域。
+INVALIDPARAMETERVALUE_INVALIDREGIONIDERROR = 'InvalidParameterValue.InvalidRegionIdError'
+
 # 无效的可用区。
 INVALIDPARAMETERVALUE_INVALIDZONEIDERROR = 'InvalidParameterValue.InvalidZoneIdError'
 
